fn from_env_var_value(input: Result<String, VarError>) -> Option<Status>Expand description
Convert the result of std::env::var to a boolean, if the variable is set.
Names that seem to say “don’t disable” are treated as Some(false). Any
other value is treated as Some(true). (That is, we err on the side of
assuming that if you set a disable variable, you meant to disable.)
Absent environment vars, or those set to the empty string, are treated as None.