fn push_prefix(stack: &mut Vec<Component>, path: &Path)Expand description
Push the string representation of each component of path onto stack,
from last to first, so that the first component of path winds up on the
top of the stack.
(This is a separate function rather than a method for borrow-checker reasons.)