pub(crate) enum PathType {
Final,
Intermediate,
Symlink,
Content,
}Expand description
The type of a single path inspected by Verifier.
Variants
Final
This is indeed the final canonical path we were trying to resolve.
Intermediate
This is an intermediary canonical path. It should be a directory, but it might not be if the path resolution is about to fail.
Symlink
This is a symbolic link.
Content
This is a file inside the target directory.